# sbeditor

A parser for all things sb3 (and sprite3)
Lets you read **and write** sb3 files!

This is a very much work-in-progress project but the underlying functionality is complete. Currently adding a ton of
classes to `sbuild.py` so that you don't need to remember/look up block opcodes/input names

## Sb3 docs

https://en.scratch-wiki.info/wiki/Scratch_File_Format
https://en.scratch-wiki.info/wiki/List_of_Block_Opcodes

You can install sbeditor using pip:
`pip install sbeditor`
